@@ -7,7 +7,7 @@ use parent qw(Exporter);
 
 use Term::ANSIColor qw(colored);
 
-our $VERSION = '0.14'; # Don't forget to change in pod below
+our $VERSION = '0.15'; # Don't forget to change in pod below
 
 our @EXPORT = qw(
     die_fatal
@@ -28,7 +28,7 @@ our @EXPORT = qw(
 our $COLORS = {
     FATAL  => 'bold red',
     ERROR  => 'red',
-    NOTICE => 'bold green',
+    NOTICE => 'bold white',
     WARN   => 'yellow',
     INFO   => 'cyan',
     DEBUG  => 'blue',
@@ -83,7 +83,7 @@ Log::Log4Cli -- Lightweight perl logger for command line tools
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ Only builtin loglevels supported. Here they are:
     # LEVEL     VALUE   COLOR
     FATAL       -1      'bold red',
     ERROR        0      'red',
-    NOTICE       0      'bold green',
+    NOTICE       0      'bold white',
     WARN         1      'yellow',
     INFO         2      'cyan',
     DEBUG        3      'blue',
@@ -148,7 +148,7 @@ L<Term::ANSIColor|Term::ANSIColor>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Michael Samoglyadov.
+Copyright 2016,2017 Michael Samoglyadov.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
